@@ -29,7 +29,7 @@ def load_tests(__loader, tests, __pattern):
     # Loading doctests
     tests.addTests(doctest.DocTestSuite(dummypdf))
     for module_finder, name, __is_pkg in pkgutil.walk_packages(
-        dummypdf.__path__, prefix="{}.".format(dummypdf.__name__)
+        dummypdf.__path__, prefix=f"{dummypdf.__name__}."
     ):
         if name in sys.modules:
             module = sys.modules[name]
